[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
# WOE-Scoring
Monotone Weight Of Evidence Transformer and LogisticRegression model with scikit-learn API